@@ -1,6 +1,9 @@
-import requests
-from xml.etree import ElementTree as ET
 import json
+import numpy as np
+import requests
+import warnings
+from xml.etree import ElementTree as ET
+
 
 import icepyx
 
@@ -21,12 +24,21 @@ def _validate_product(product):
             "ATL04",
             "ATL06",
             "ATL07",
+            "ATL07QL",
             "ATL08",
             "ATL09",
+            "ATL09QL",
             "ATL10",
             "ATL11",
             "ATL12",
             "ATL13",
+            "ATL14",
+            "ATL15",
+            "ATL16",
+            "ATL17",
+            "ATL19",
+            "ATL20",
+            "ATL21",
         ], "Please enter a valid product"
     else:
         raise TypeError("Please enter a product string")
@@ -250,3 +262,57 @@ def _default_varlists(product):
             "THE REQUESTED PRODUCT DOES NOT YET HAVE A DEFAULT LIST SET UP. ONLY DELTA_TIME, LATITUTDE, AND LONGITUDE WILL BE RETURNED"
         )
         return common_list
+
+
+def gt2spot(gt, sc_orient):
+
+    assert gt in [
+        "gt1l",
+        "gt1r",
+        "gt2l",
+        "gt2r",
+        "gt3l",
+        "gt3r",
+    ], "An invalid ground track was found"
+
+    gr_num = np.uint8(gt[2])
+    gr_lr = gt[3]
+
+    if sc_orient == 1:
+        if gr_num == 1:
+            if gr_lr == "l":
+                spot = 2
+            elif gr_lr == "r":
+                spot = 1
+        elif gr_num == 2:
+            if gr_lr == "l":
+                spot = 4
+            elif gr_lr == "r":
+                spot = 3
+        elif gr_num == 3:
+            if gr_lr == "l":
+                spot = 6
+            elif gr_lr == "r":
+                spot = 5
+
+    elif sc_orient == 0:
+        if gr_num == 1:
+            if gr_lr == "l":
+                spot = 5
+            elif gr_lr == "r":
+                spot = 6
+        elif gr_num == 2:
+            if gr_lr == "l":
+                spot = 3
+            elif gr_lr == "r":
+                spot = 4
+        elif gr_num == 3:
+            if gr_lr == "l":
+                spot = 1
+            elif gr_lr == "r":
+                spot = 2
+
+    if "spot" not in locals():
+        raise ValueError("Could not compute the spot number.")
+
+    return np.uint8(spot)
